@@ -11,7 +11,7 @@ __author__ = "Lyam Baudry, \
               Cyril Matthey-Doret, \
               Rémi Montagne, \
               Vittore Scolari"
-__copyright__ = "Copyright © 2017-2018, Institut Pasteur, Paris, France"
+__copyright__ = "Copyright © 2017-2019, Institut Pasteur, Paris, France"
 __credits__ = [
     "Lyam Baudry",
     "Axel Cournac",
@@ -22,5 +22,5 @@ __credits__ = [
 __license__ = "GPLv3"
 __maintainer__ = "Lyam Baudry, \
                   Cyril Matthey-Doret"
-__email__ = "lyam.baudry@pasteur.fr"
-__status__ = "Alpha"
+__email__ = "lyam.baudry@pasteur.fr, cmdoret@pasteur.fr"
+__status__ = "Beta"
